==> symbol-processing-aa-embeddable-2.2.0-2.0.2-sources.jar: org/jetbrains/kotlin/psi/stubs/elements/KtBlockStringTemplateEntryElementType.kt <==
/*
 * Copyright 2010-2025 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.psi.stubs.elements

import ksp.com.intellij.psi.stubs.StubElement
import ksp.com.intellij.psi.stubs.StubInputStream
import ksp.com.intellij.psi.stubs.StubOutputStream
import ksp.com.intellij.psi.util.childrenOfType
import ksp.org.jetbrains.annotations.NonNls
import ksp.org.jetbrains.kotlin.psi.KtBlockStringTemplateEntry
import ksp.org.jetbrains.kotlin.psi.KtExpression
import ksp.org.jetbrains.kotlin.psi.stubs.KotlinBlockStringTemplateEntryStub
import ksp.org.jetbrains.kotlin.psi.stubs.impl.KotlinBlockStringTemplateEntryStubImpl

class KtBlockStringTemplateEntryElementType(@NonNls debugName: String) :
    KtStubElementType<KotlinBlockStringTemplateEntryStub, KtBlockStringTemplateEntry>(
        debugName,
        KtBlockStringTemplateEntry::class.java,
        KotlinBlockStringTemplateEntryStub::class.java,
    ) {

    override fun createStub(
        psi: KtBlockStringTemplateEntry,
        parentStub: StubElement<*>?,
    ): KotlinBlockStringTemplateEntryStub = KotlinBlockStringTemplateEntryStubImpl(
        parentStub,
        hasMultipleExpressions = psi.childrenOfType<KtExpression>().size > 1,
        text = psi.text,
    )

    override fun serialize(
        stub: KotlinBlockStringTemplateEntryStub,
        dataStream: StubOutputStream,
    ) {
        dataStream.writeBoolean(stub.hasMultipleExpressions)
        dataStream.writeUTFFast(stub.text())
    }

    override fun deserialize(
        dataStream: StubInputStream,
        parentStub: StubElement<*>?,
    ): KotlinBlockStringTemplateEntryStub {
        val hasMultipleExpressions = dataStream.readBoolean()
        val text = dataStream.readUTFFast()
        return KotlinBlockStringTemplateEntryStubImpl(
            parent = parentStub,
            hasMultipleExpressions = hasMultipleExpressions,
            text = text,
        )
    }
}

==> symbol-processing-aa-embeddable-2.2.20-2.0.4-sources.jar: org/jetbrains/kotlin/psi/stubs/elements/KtBlockStringTemplateEntryElementType.kt <==
/*
 * Copyright 2010-2025 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.psi.stubs.elements

import ksp.com.intellij.psi.stubs.StubElement
import ksp.com.intellij.psi.stubs.StubInputStream
import ksp.com.intellij.psi.stubs.StubOutputStream
import ksp.com.intellij.psi.util.childrenOfType
import ksp.org.jetbrains.annotations.NonNls
import ksp.org.jetbrains.kotlin.psi.KtBlockStringTemplateEntry
import ksp.org.jetbrains.kotlin.psi.KtExpression
import ksp.org.jetbrains.kotlin.psi.stubs.KotlinBlockStringTemplateEntryStub
import ksp.org.jetbrains.kotlin.psi.stubs.impl.KotlinBlockStringTemplateEntryStubImpl

class KtBlockStringTemplateEntryElementType(@NonNls debugName: String) :
    KtStubElementType<KotlinBlockStringTemplateEntryStubImpl, KtBlockStringTemplateEntry>(
        debugName,
        KtBlockStringTemplateEntry::class.java,
        KotlinBlockStringTemplateEntryStub::class.java,
    ) {

    override fun createStub(
        psi: KtBlockStringTemplateEntry,
        parentStub: StubElement<*>?,
    ): KotlinBlockStringTemplateEntryStubImpl = KotlinBlockStringTemplateEntryStubImpl(
        parentStub,
        hasMultipleExpressions = psi.childrenOfType<KtExpression>().size > 1,
        text = psi.text,
    )

    override fun serialize(
        stub: KotlinBlockStringTemplateEntryStubImpl,
        dataStream: StubOutputStream,
    ) {
        dataStream.writeBoolean(stub.hasMultipleExpressions)
        dataStream.writeUTFFast(stub.text)
    }

    override fun deserialize(
        dataStream: StubInputStream,
        parentStub: StubElement<*>?,
    ): KotlinBlockStringTemplateEntryStubImpl {
        val hasMultipleExpressions = dataStream.readBoolean()
        val text = dataStream.readUTFFast()
        return KotlinBlockStringTemplateEntryStubImpl(
            parent = parentStub,
            hasMultipleExpressions = hasMultipleExpressions,
            text = text,
        )
    }
}
